@@ -7,11 +7,10 @@
 #' \item{\code{logical vector/matrix/data.frame}}{ NA's will be set in places
 #' where \code{value} is TRUE. \code{value} will be recycled if needed.}
 #' \item{\code{function}}{ NA's will be set in places where \code{value(x)} is 
-#' TRUE. Function will be applied columnwise. Additionally, there are special
-#' functions for common cases of comparison. For example
-#' \code{na_if(my_var, gt(98))} will replace all values greater 98 in
-#' \code{my_var} with NA. For detailed description of
-#' special functions see \link{criteria}} }
+#' TRUE. Function will be applied columnwise. Additionally, there are special 
+#' functions for common cases of comparison. For example \code{na_if(my_var,
+#' gt(98))} will replace all values which are greater than 98 in \code{my_var}
+#' with NA. For detailed description of special functions see \link{criteria}} }
 #' 
 #' @param x vector/matrix/data.frame/list
 #' @param value vector/matrix/data.frame/function
@@ -51,6 +50,7 @@
 #' na_if(a, -1 %thru% 1)
 #' @export
 na_if = function(x, value){
+    if(!length(value)) return(x)
     if_val(x, from=list(value)) = list(NA)
     x
 }
