@@ -12,6 +12,8 @@ b_4 = -4 %r% 5
 b_5 = -5 %r% 5 
 
 dfs = data.frame(
+    zz = 42,
+    b_3 = 44,
     aa = 10 %r% 5,
     b_ = 20 %r% 5,
     b_1 = 11 %r% 5,
@@ -20,8 +22,13 @@ dfs = data.frame(
     b_5 = 15 %r% 5 
 )
 
+expect_error(modify(dfs, {.n = 42}))
+expect_error(modify(dfs, {.N = 42}))
+expect_error(modify(dfs, {set = 42}))
+
+
+
 result_dfs = dfs
-result_dfs$a_total = sum_row(a_1, a_2, a_4, a_5)
 result_dfs$b_total = with(dfs, sum_row(b_1, b_2, b_4, b_5))
 set.seed(1)
 result_dfs$b_total = with(dfs, sum_row(b_1, b_2, b_4, b_5))
@@ -35,30 +42,77 @@ result_dfs2 = dfs2
 result_dfs2$b_total = ifelse(dfs2$test %in% 2:4, with(dfs, sum_row(b_1, b_2, b_4, b_5)), NA)
 result_dfs2$aa = ifelse(dfs2$test %in% 2:4, result_dfs2$aa+1, result_dfs2$aa)
 
+expect_identical(calc(dfs, sum_row(b_1 %to% b_5)), result_dfs$b_total)
+
+default_dataset(dfs)
+expect_identical(.calc(sum_row(b_1 %to% b_5)), result_dfs$b_total)
+
+expect_identical(dfs %calc% sum_row(b_1 %to% b_5), result_dfs$b_total)
+set.seed(1)
+expect_identical(calc(dfs, runif(.N)), result_dfs$random_numer)
+
 set.seed(1)
 expect_identical(
     modify(dfs, {
-        a_total = sum_row(vars_range("a_1", "a_5"))
-        b_total = sum_row(vars_range("b_1", "b_5"))
+        b_total = sum_row(vars(b_1 %to% b_5))
         random_numer = runif(.n)
     }), 
     result_dfs
 )
 
+set.seed(1)
+expect_identical(
+    modify(dfs, {
+        b_total = sum_row(vars(from("b_1") & to("b_5")))
+        random_numer = runif(.n)
+    }), 
+    result_dfs
+)
+
+set.seed(1)
+expect_identical(
+    compute(dfs, {
+        b_total = sum_row(vars(b_1 %to% b_5))
+        random_numer = runif(.n)
+    }), 
+    result_dfs
+)
+
+
+
+# Bad number of rows: 'random_numer' has 2 rows instead of 5 rows. 
+expect_error(
+    modify(dfs, {
+        random_numer = runif(2)
+    })
+)
+
+
 set.seed(1)
 expect_identical(
     dfs %modify% {
-        a_total = sum_row(vars_range("a_1", "a_5"))
-        b_total = sum_row(vars_range("b_1", "b_5"))
+        b_total = sum_row(vars(b_1 %to% b_5))
         random_numer = runif(.n)
     }, 
     result_dfs
 )
 
+
+set.seed(1)
+expect_identical(
+    dfs %compute% {
+        b_total = sum_row(vars(from("b_1") & to("b_5")))
+        random_numer = runif(.n)
+    }, 
+    result_dfs
+)
+
+
+
+
 result_dfs$random_numer = NULL
 expect_identical(
     modify(dfs, {
-        a_total = sum_row(a_1 %to% a_5)
         b_total = sum_row(b_1 %to% b_5)
     }), 
     result_dfs
@@ -67,7 +121,6 @@ expect_identical(
 result_dfs$random_numer = NULL
 expect_identical(
     dfs %modify% {
-        a_total = sum_row(a_1 %to% a_5)
         b_total = sum_row(b_1 %to% b_5)
     }, 
     result_dfs
@@ -77,15 +130,20 @@ context("modify magrittr")
 if(suppressWarnings(require(magrittr, quietly = TRUE))){
     expect_identical(
         dfs %>% modify( {
-            a_total = sum_row(vars_range("a_1", "a_5"))
-            b_total = sum_row(vars_range("b_1", "b_5"))
+            b_total = sum_row(vars(from("b_1") & to("b_5")))
+        }), 
+        result_dfs
+    )
+    
+    expect_identical(
+        dfs %>% modify( {
+            b_total = sum_row(vars(b_1 %to% b_5))
         }), 
         result_dfs
     )
     
     expect_identical(
         dfs %>% modify( {
-            a_total = sum_row(a_1 %to% a_5)
             b_total = sum_row(b_1 %to% b_5)
         }), 
         result_dfs
@@ -98,22 +156,29 @@ if(suppressWarnings(require(magrittr, quietly = TRUE))){
 # example with dplyr
 context("modify dplyr")
 if(suppressWarnings(require(dplyr, quietly = TRUE))){
+    
     expect_identical(
         tbl_df(dfs) %>% modify( {
-            a_total = sum_row(vars_range("a_1", "a_5"))
-            b_total = sum_row(vars_range("b_1", "b_5"))
+            b_total = rowSums(vars(from("b_1") & to("b_5")))
+        }), 
+        tbl_df(result_dfs)
+    )
+    
+    expect_identical(
+        tbl_df(dfs) %>% modify( {
+            b_total = rowSums(vars(b_1 %to% b_5))
         }), 
         tbl_df(result_dfs)
     )
     
     expect_identical(
         tbl_df(dfs) %>% modify( {
-            a_total = sum_row(a_1 %to% a_5)
             b_total = sum_row(b_1 %to% b_5)
         }), 
         tbl_df(result_dfs)
     )
     
+    
 } else {
     cat("dplyr not found\n")
 }
@@ -134,6 +199,40 @@ expect_identical(
 )
 
 
+set.seed(1)
+expect_identical(
+    modify_if(dfs2, 2:4,
+              {
+                  b_total = sum_row(b_1 %to% b_5)
+                  aa = aa + 1
+                  random_numer = runif(.n)
+              }), 
+    result_dfs2
+)
+
+
+set.seed(1)
+expect_identical(
+    modify_if(dfs2, test %in% 2:4,
+              {
+                  b_total = sum_row(b_1 %to% b_5)
+                  aa = aa + 1
+                  random_numer = runif(.N)
+              }), 
+    result_dfs2
+)
+
+
+set.seed(1)
+expect_identical(
+    do_if(dfs2, test %in% 2:4,
+              {
+                  b_total = sum_row(b_1 %to% b_5)
+                  aa = aa + 1
+                  random_numer = runif(.N)
+              }), 
+    result_dfs2
+)
 
 
 expect_error(
@@ -144,6 +243,9 @@ expect_error(
                   aa = aa + 1
               })
 )
+expect_error(modify_if(dfs2,test %in% 2:4,  {.n = 42}))
+expect_error(modify_if(dfs2,test %in% 2:4,  {.N = 42}))
+expect_error(modify_if(dfs2,test %in% 2:4,  {set = 42}))
 
 
 result_dfs2$random_numer = NULL
@@ -182,6 +284,16 @@ expect_identical(
     result_dfs2
 )
 
+
+expect_identical(
+    modify_if(dfs2, 2:4,
+              {
+                  b_total = NULL
+                  aa = aa + 1
+              }), 
+    result_dfs2
+)
+
 context("modify labels")
 
 result_dfs3 = dfs
@@ -257,5 +369,27 @@ iris2 = modify_if(iris2, Sepal.Length<5, {Species = NULL})
 expect_identical(iris2, iris[,-5])
 
 
+#### 
+context("modify.list/modify_if.list")
+
+data(iris)
+iris_list = split(iris, iris$Species)
 
 
+res = lapply(iris_list, function(dfs) {dfs$aggr = sum(dfs$Sepal.Length); dfs})
+
+res0 = modify(iris_list, {aggr = sum(Sepal.Length)})
+expect_identical(res0, res)
+
+res_calc = calc(iris_list, sum(Sepal.Length))
+expect_identical(res_calc, lapply(iris_list, function(dfs){sum(dfs$Sepal.Length)}))
+
+
+
+res = lapply(iris_list, function(dfs) {
+    dfs$aggr = ifelse(dfs$Sepal.Width>mean(dfs$Sepal.Width), 1, NA)
+    dfs
+    })
+
+res0 = modify_if(iris_list, Sepal.Width>mean(Sepal.Width), {aggr = 1})
+expect_identical(res0, res)
\ No newline at end of file
