@@ -1,14 +1,29 @@
 context("vlookup data.frame")
 
 dict = data.frame(num=1:26,small=letters,cap=LETTERS,stringsAsFactors = FALSE)
+dict_mat = cbind(num=1:26,small=letters,cap=LETTERS)
 rownames(dict) = paste0('rows',1:26)
+rownames(dict_mat) = paste0('rows',1:26)
 expect_identical(vlookup_df(1:3,dict),dict[1:3,]) 
 
 expect_identical(vlookup(c(45,1:3,58,NA),dict,result_column='cap'),c(NA,"A", "B", "C", NA,NA))
+expect_identical(vlookup(c(45,1:3,58,NA),dict_mat,result_column='cap'),c(NA,"A", "B", "C", NA,NA))
 expect_identical(vlookup_df(c('z','d','f','d'),dict,lookup_column = 'small'),dict[c(26,4,6,4),])
 expect_identical(vlookup_df(c('rows1','rows5','rows2','rows2'),dict,result_column = c("small","cap"),lookup_column = 'row.names'),
                  dict[c(1,5,2,2),c("small","cap")])
 
+expect_identical(vlookup_df(c('rows1','rows5','rows2','rows2'),dict,result_column = c("small","cap", "names"),
+                            lookup_column = 'row.names'),
+                 dtfrm(dict[c(1,5,2,2),c("small","cap")], row_names = rownames(dict)[c(1,5,2,2)]))
+
+expect_identical(vlookup_df(c('rows1','rows5','rows2','rows2'), dict, result_column = c("row.names", "small","cap"),
+                            lookup_column = 'row.names'),
+                 dtfrm(row_names = rownames(dict)[c(1,5,2,2)], dict[c(1,5,2,2),c("small","cap")]))
+
+expect_identical(vlookup_df(c('z','d','f','d'),dict_mat,lookup_column = 'small'),as.dtfrm(dict_mat)[c(26,4,6,4),, drop = FALSE])
+expect_identical(vlookup_df(c('rows1','rows5','rows2','rows2'),dict_mat,result_column = c("small","cap"),lookup_column = 'row.names'),
+                 as.dtfrm(dict)[c(1,5,2,2),c("small","cap")])
+
 expect_error(vlookup(c('rows1','rows5','rows2','rows2'),dict,result_column = c("small","cap"),lookup_column = 'row.names'))
 
 context("vlookup tbl_df")
@@ -16,13 +31,13 @@ if(suppressWarnings(require(dplyr, quietly = TRUE))){
 
     
     dict = tbl_df(data.frame(num=1:26, small=letters, cap=LETTERS, stringsAsFactors = FALSE))
-    rownames(dict) = paste0('rows',1:26)
-    expect_identical(vlookup_df(1:3, dict), dict[1:3,]) 
+    # rownames(dict) = paste0('rows',1:26)
+    expect_identical(vlookup_df(1:3, dict), dict[1:3,])
     
     expect_identical(vlookup(c(45, 1:3, 58, NA), dict, result_column='cap'), c(NA, "A", "B", "C", NA, NA))
     expect_identical(vlookup_df(c('z', 'd', 'f', 'd'), dict, lookup_column = 'small'), dict[c(26, 4, 6, 4),])
-    expect_identical(vlookup_df(c('rows1', 'rows5', 'rows2', 'rows2'), dict, result_column = c("small", "cap"), lookup_column = 'row.names'),
-                     dict[c(1, 5, 2, 2), c("small", "cap")])
+    # expect_identical(vlookup_df(c('rows1', 'rows5', 'rows2', 'rows2'), dict, result_column = c("small", "cap"), lookup_column = 'row.names'),
+    #                  dict[c(1, 5, 2, 2), c("small", "cap")])
     
 } else {
 	cat("dplyr not found\n")
@@ -36,7 +51,17 @@ expect_identical(vlookup(c(6, 4, 2), dict, result_column='row.names'),c("f","d",
 expect_identical(vlookup(c(6, 4, 2), dict, result_column='rownames'),c("f","d","b"))
 expect_identical(vlookup(c(6, 4, 2), dict, result_column='names'),c("f","d","b"))
 
+expect_identical(vlookup(c("f","d","b"), dict, result_column = 1, lookup_column='row.names'), c(6L, 4L, 2L))
+expect_identical(vlookup(c("f","d","b"), dict, result_column = 1, lookup_column='rownames'), c(6L, 4L, 2L))
+expect_identical(vlookup(c("f","d","b"), dict, result_column = 1, lookup_column='names'), c(6L, 4L, 2L))
 
+expect_identical(vlookup(c("f","d","b"), dict, result_column = NULL, lookup_column='row.names'), c(6L, 4L, 2L))
+expect_identical(vlookup(c("f","d","b"), dict, result_column = NULL, lookup_column='rownames'), c(6L, 4L, 2L))
+expect_identical(vlookup(c("f","d","b"), dict, result_column = NULL, lookup_column='names'), c(6L, 4L, 2L))
+
+expect_identical(vlookup_df(c(6, 4, 2), dict, result_column='row.names'),dtfrm(row_names = c("f","d","b")))
+expect_identical(vlookup_df(c(6, 4, 2), dict, result_column='rownames'),dtfrm(row_names = c("f","d","b")))
+expect_identical(vlookup_df(c(6, 4, 2), dict, result_column='names'),dtfrm(row_names = c("f","d","b")))
 
 context("vlookup excel examples ex2")
 
